@@ -19,14 +19,15 @@
 //!
 //! * `Share`等同于`std::sync::Arc`,
 //! * `ShareWeak`等同于`std::sync::Weak`.
-//! * `ShareMutex`等同于`std::sync::Mutex`
-//! * `ShareRwLock`等同于`std::sync::RwLock`
+//! * `ShareMutex`等同于`parking_lot::Mutex`
+//! * `ShareRwLock`等同于`parking_lot::RwLock`
 //! * `ShareCell`等同于`cell::TrustCell`
 //! * `ShareBool`等同于`RefCell<bool>`
 //! * `ShareU8`等同于`RefCell<u8>`
 //! * `ShareUsize`等同于`RefCell<usize>`
 //! * `SharePtr`等同于`RefCell<T>`
 //! * `ShareRefCell`等同于`Arc(TrustCell<T>)`
+//! 
 
 #![feature(const_trait_impl)]
 
@@ -64,17 +65,17 @@ pub use rc_refcell::RcRefCell as ShareRefCell;
 
 #[cfg(not(feature = "rc"))]
 use std::sync::{
-    atomic::AtomicBool, atomic::AtomicPtr, atomic::AtomicU8, atomic::AtomicUsize, Arc, Mutex,
-    RwLock, Weak,
+    atomic::AtomicBool, atomic::AtomicPtr, atomic::AtomicU8, atomic::AtomicUsize, Arc, 
+    Weak,
 };
 #[cfg(not(feature = "rc"))]
 pub type Share<T> = Arc<T>;
 #[cfg(not(feature = "rc"))]
 pub type ShareWeak<T> = Weak<T>;
 #[cfg(not(feature = "rc"))]
-pub type ShareMutex<T> = Mutex<T>;
+pub type ShareMutex<T> = parking_lot::Mutex<T>;
 #[cfg(not(feature = "rc"))]
-pub type ShareRwLock<T> = RwLock<T>;
+pub type ShareRwLock<T> = parking_lot::RwLock<T>;
 #[cfg(not(feature = "rc"))]
 pub type ShareCell<T> = cell::TrustCell<T>;
 #[cfg(not(feature = "rc"))]
